@@ -16,7 +16,7 @@ class UrlMap(object):
     
     def add_rule(self, url, target, name=None):
         if self.url_prefix:
-            url = '/%s/%s' % (self.url_prefix.strip('/'), url.lstrip('/'))
+            url = '/%s/%s' % (self.url_prefix, url.lstrip('/'))
         dirs = url.split('/')[1:]
         cur = self.tree
         vars = []
@@ -171,7 +171,7 @@ def add_apps(apps):
     for mod in apps:
         if isinstance(mod, tuple):
             mod, prefix = mod
-            urls.url_prefix = prefix
+            urls.url_prefix = prefix.strip().strip('/') or None
         app_name = '%s.%s' % (mod, 'views')
         __import__(app_name)
         urls.url_prefix = None
