@@ -36,6 +36,8 @@ def render_to_string(fn, context):
     
 def render_to_response(rq, fn, context=None, **response_kwargs):
     context = context or {}
-    rq.context.update(context)
-    return wsgi.Response(render_to_string(fn, rq.context), **response_kwargs)
+    for k, v in rq.context.iteritems():
+        if k not in context:
+            context[k] = v
+    return wsgi.Response(render_to_string(fn, context), **response_kwargs)
     
